
<!--
FrozenIsBool False
-->

#Setter

##Doc
----


> 
> A Setter has a __setitem__ method for setting things in the <InstanceVariable>.__dict__
> 
> 

----

<small>
View the Setter notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Setter.ipynb)
</small>

